@@ -4,10 +4,10 @@ from coopr.pyomo.base import Constraint, Objective, Var, maximize
 from coopr.pyomo.base import expr, var
 from coopr.pyomo.base import param
 from coopr.pyomo.base import numvalue
+from coopr.pyomo.io.cpxlp import CPXLP_numeric_labeler
 from coopr.opt import SymbolMap
 try:
     import FuncDesigner
-    import FuncDesignerExt
     FD_available=True
 except ImportError:
     FD_available=False
@@ -15,9 +15,22 @@ except ImportError:
 import logging
 logger = logging.getLogger('coopr.pyomo')
 
+labeler = CPXLP_numeric_labeler('x')
 
 if FD_available:
 
+    try:
+        tanh = FuncDesigner.tanh
+        arcsinh = FuncDesigner.arcsinh
+        arccosh = FuncDesigner.arccosh
+        arctanh = FuncDesigner.arctanh
+    except:
+        import FuncDesignerExt
+        tanh = FuncDesignerExt.tanh
+        arcsinh = FuncDesignerExt.arcsinh
+        arccosh = FuncDesignerExt.arccosh
+        arctanh = FuncDesignerExt.arctanh
+
     def fd_pow(x,y):
         return x**y
 
@@ -29,15 +42,15 @@ if FD_available:
         'tan':FuncDesigner.tan,
         'sinh':FuncDesigner.sinh,
         'cosh':FuncDesigner.cosh,
-        'tanh':FuncDesignerExt.tanh,
+        'tanh':FuncDesigner.tanh,
         'asin':FuncDesigner.arcsin,
         'acos':FuncDesigner.arccos,
         'atan':FuncDesigner.arctan,
         'exp':FuncDesigner.exp,
         'sqrt':FuncDesigner.sqrt,
-        'asinh':FuncDesignerExt.arcsinh,
-        'acosh':FuncDesignerExt.arccosh,
-        'atanh':FuncDesignerExt.arctanh,
+        'asinh':FuncDesigner.arcsinh,
+        'acosh':arccosh,
+        'atanh':arctanh,
         'pow':fd_pow,
         'abs':FuncDesigner.abs,
         'ceil':FuncDesigner.ceil,
@@ -99,15 +112,11 @@ def Pyomo2FD_expression(exp, ipoint, vars, symbol_map):
         return Pyomo2FD_expression(exp._args[0], ipoint, vars, symbol_map)
 
     elif (isinstance(exp,var._VarData) or isinstance(exp,var.Var)) and not exp.fixed_value():
-        global id_counter
-        if exp.id is None:
-            exp.id = id_counter
-            id_counter += 1
-        vname = 'x'+str(exp.id)
+        vname = symbol_map.getSymbol(exp, labeler)
         if not vname in vars:
             vars[vname] = FuncDesigner.oovar(vname)
             ipoint[vars[vname]] = 0.0 if exp.value is None else exp.value
-            symbol_map.getSymbol(exp, lambda obj,x: x, vname)
+            #symbol_map.getSymbol(exp, lambda obj,x: x, vname)
         return vars[vname]
 
     elif isinstance(exp,param._ParamData):
